==> tap_schema_manager-v1.0.0.zip: tap_schema_manager-v1.0.0/TapSchemaManagerWebApp/src/test/java/TapSchemaMangerTest.java <==
/* 
 * _____________________________________________________________________________
 * 
 * INAF - OATS National Institute for Astrophysics - Astronomical Observatory of
 * Trieste INAF - IA2 Italian Center for Astronomical Archives
 * _____________________________________________________________________________
 * 
 * Copyright (C) 2016 Istituto Nazionale di Astrofisica
 * 
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License Version 3 as published by the
 * Free Software Foundation.
 * 
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
 * details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, write to the Free Software Foundation, Inc., 51
 * Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 */
import it.inaf.oats.ia2.tapschemamanager.webapp.CredentialsConfiguration;
import it.inaf.oats.ia2.tapschemamanager.webapp.SeparateCredentials;
import it.inaf.oats.ia2.tapschemamanager.api.Credentials;
import java.io.StringReader;
import java.io.StringWriter;
import javax.xml.bind.JAXB;
import org.junit.After;
import org.junit.AfterClass;
import org.junit.Before;
import org.junit.BeforeClass;
import org.junit.Test;
import static org.junit.Assert.*;
import org.junit.Ignore;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

/**
 *
 * @author Sonia Zorba {@literal <zorba at oats.inaf.it>}
 */
public class TapSchemaMangerTest {

    private static final Logger log = LoggerFactory.getLogger(TapSchemaMangerTest.class);

    public TapSchemaMangerTest() {
    }

    @BeforeClass
    public static void setUpClass() {
    }

    @AfterClass
    public static void tearDownClass() {
    }

    @Before
    public void setUp() {
    }

    @After
    public void tearDown() {
    }

    @Test
    public void testCredentialsConfigSerialization() throws Exception {
        CredentialsConfiguration cc = new CredentialsConfiguration();

        cc.addCredentials(new Credentials());

        SeparateCredentials sc = new SeparateCredentials();
        sc.setSourceCredentials(new Credentials());
        sc.setTapSchemaCredentials(new Credentials());
        cc.addSeparateCredentials(sc);

        StringWriter sw = new StringWriter();
        JAXB.marshal(cc, sw);

        StringReader sr = new StringReader(sw.toString());

        cc = JAXB.unmarshal(sr, CredentialsConfiguration.class);
        sw = new StringWriter();
        JAXB.marshal(cc, sw);

        log.debug(sw.toString());
        sw.close();
    }
}

==> tap_schema_manager-v1.0.4.zip: tap_schema_manager-v1.0.4/TapSchemaManagerWebApp/src/test/java/TapSchemaMangerTest.java <==
/* 
 * _____________________________________________________________________________
 * 
 * INAF - OATS National Institute for Astrophysics - Astronomical Observatory of
 * Trieste INAF - IA2 Italian Center for Astronomical Archives
 * _____________________________________________________________________________
 * 
 * Copyright (C) 2016 Istituto Nazionale di Astrofisica
 * 
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License Version 3 as published by the
 * Free Software Foundation.
 * 
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
 * details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, write to the Free Software Foundation, Inc., 51
 * Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 */
import it.inaf.ia2.tsm.webapp.CredentialsConfiguration;
import it.inaf.ia2.tsm.webapp.SeparateCredentials;
import it.inaf.ia2.tsm.api.Credentials;
import java.io.StringReader;
import java.io.StringWriter;
import javax.xml.bind.JAXB;
import org.junit.After;
import org.junit.AfterClass;
import org.junit.Before;
import org.junit.BeforeClass;
import org.junit.Test;
import static org.junit.Assert.*;
import org.junit.Ignore;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

/**
 *
 * @author Sonia Zorba {@literal <zorba at oats.inaf.it>}
 */
public class TapSchemaMangerTest {

    private static final Logger log = LoggerFactory.getLogger(TapSchemaMangerTest.class);

    public TapSchemaMangerTest() {
    }

    @BeforeClass
    public static void setUpClass() {
    }

    @AfterClass
    public static void tearDownClass() {
    }

    @Before
    public void setUp() {
    }

    @After
    public void tearDown() {
    }

    @Test
    public void testCredentialsConfigSerialization() throws Exception {
        CredentialsConfiguration cc = new CredentialsConfiguration();

        cc.addCredentials(new Credentials());

        SeparateCredentials sc = new SeparateCredentials();
        sc.setSourceCredentials(new Credentials());
        sc.setTapSchemaCredentials(new Credentials());
        cc.addSeparateCredentials(sc);

        StringWriter sw = new StringWriter();
        JAXB.marshal(cc, sw);

        StringReader sr = new StringReader(sw.toString());

        cc = JAXB.unmarshal(sr, CredentialsConfiguration.class);
        sw = new StringWriter();
        JAXB.marshal(cc, sw);

        log.debug(sw.toString());
        sw.close();
    }
}
